/*****************************************************************************

  HelloWorld

  Draws a smiling face using 3 circles, a circle arc and a triangle.
  Use 'Break' in the 'Extras' menu to abort the simulation loop or just simply
  quit.

  $Name: Funplot_v10 $
  $Revision: 1.1 $
  $Date: 2006/03/02 20:09:05 $

  Copyright (C) 1998-2006 Domenico Reggio, Software-Engineering.

*****************************************************************************/

#include "Funplot.h"
#include <math.h>


// Function declaration for drawing an Ellipse
// (You find the source code at the end of file)
void DrawEllipseArc(Funplot *FunWin, short graphNumber,
                    double majorAxis, double minorAxis,
                    double midpointX, double midpointY,
                    double phiStartDeg, double phiStopDeg);


// Main Program / Entry function for a Windows based application
int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                   LPSTR lpszCmdLine, int nCmdShow)
{
  // Register the Funplot window class
  Funplot::ClassRegister(hInstance, hPrevInstance, nCmdShow);

  // Program variables
  double phiBeg, phiEnd, midX, midY, majAxis, minAxis, radius;
  short  graphNum;

  // Instantiation of a Funplot window
  Funplot HelloWin("Hello World");
  HelloWin.SetLables("Horizontal Smile","Vertical Smile",
                     "Hello to the World !");
  HelloWin.SetRange(-100,100,-100,100);
  HelloWin.SetNumGraphs(4);
  HelloWin.SetGraphLineWidth(3);
  HelloWin.SetGraphLable("Nose",1);
  HelloWin.SetGraphLable("Face",2);
  HelloWin.SetGraphLable("Glasses",3);
  HelloWin.SetGraphLable("Mouth",4);
  HelloWin.ShowCoorSystem(HIDE);
  HelloWin.ShowGrid(HIDE);
  HelloWin.SetAspectRatio(AXES_EQUAL);
  HelloWin.Rise();

  // Draw the nose as triangle to graph 0 in cyan
  graphNum= 1;
  HelloWin.SetGraphColorNum(4, graphNum);
  HelloWin.LineTo(-10, -20, graphNum);   // First call moves to point
  HelloWin.LineTo(  0,  15, graphNum);
  HelloWin.LineTo( 10, -20, graphNum);
  HelloWin.LineTo(-10, -20, graphNum);   // Connect to first point

  // Draw the face outline to graph 1 in green
  graphNum= 2;
  HelloWin.SetGraphColorNum(2, graphNum);   // Set color of graph
  radius= 80;    // Circle Radius
  midX= 0;       // Coordinates of midpoint
  midY= 0;
  phiBeg=   0;   // Start and End angle of ellipse arc
  phiEnd= 360;
  DrawEllipseArc(&HelloWin, graphNum, radius, radius,
                 midX, midY, phiBeg, phiEnd);

  // Draw the glasses as ellipses with line joints to graph 2 in blue
  graphNum= 3;
  HelloWin.SetGraphColorNum(3, graphNum);
  majAxis= 20;   // ellipse semimajor and semiminor axis
  minAxis= 15;
  midX= 35;
  midY= 40;
  phiBeg=   0;
  phiEnd= 360;
  DrawEllipseArc(&HelloWin, graphNum, majAxis, minAxis,   // Right eye
                 midX, midY, phiBeg, phiEnd);
  HelloWin.NewLine(graphNum);   // Begin a new line
  midX= -35;
  midY=  40;
  DrawEllipseArc(&HelloWin, graphNum, majAxis, minAxis,   // Left eye
                 midX, midY, phiBeg, phiEnd);
  HelloWin.NewLine(graphNum);   // Begin a new line
  HelloWin.LineTo( 15, 40, graphNum);
  HelloWin.LineTo(-15, 40, graphNum);
  HelloWin.NewLine(graphNum);   // Begin a new line
  HelloWin.LineTo( 55, 40, graphNum);
  HelloWin.LineTo( 65, 45, graphNum);
  HelloWin.NewLine(graphNum);   // Begin a new line
  HelloWin.LineTo(-55, 40, graphNum);
  HelloWin.LineTo(-65, 45, graphNum);

  // Draw the mouth as circle arc to graph 3 in red
  graphNum= 4;
  HelloWin.SetGraphColorNum(1, graphNum);
  radius= 50;
  midX=   0;
  midY= -10;
  phiBeg= 200;
  phiEnd= 340;
  DrawEllipseArc(&HelloWin, graphNum, radius, radius,
                 midX, midY, phiBeg, phiEnd);

  // Enter the 'endless' message loop
  Funplot::MessageLoop();

  return 0;
}


void DrawEllipseArc(Funplot *FunWin, short graphNumber,
                    double majorAxis, double minorAxis,
                    double midpointX, double midpointY,
                    double phiStartDeg, double phiStopDeg)
{
  double x, y, phi, phiStartRad, phiStopRad;
  double PI= 3.1415926;

  phiStartRad= phiStartDeg*PI/180;
  phiStopRad=  phiStopDeg*PI/180;

  for (phi=phiStartRad; phi<=phiStopRad; phi+=PI/180)
  {
    x= majorAxis*cos(phi) +midpointX;
    y= minorAxis*sin(phi) +midpointY;
    FunWin->LineTo(x,y,graphNumber);
  }
}
